@@ -4,6 +4,7 @@
 package e2e
 
 import (
+	"fmt"
 	"strings"
 	"testing"
 
@@ -32,6 +33,33 @@ func TestWaitTimeout(t *testing.T) {
        restartPolicy: Never
 `
 
+	yaml2 := `
+apiVersion: v1
+kind: Pod
+metadata:
+  name: nginx
+spec:
+  containers:
+  - name: nginx
+    image: %s
+    ports:
+    - containerPort: 80
+---
+apiVersion: kapp.k14s.io/v1alpha1
+kind: Config
+waitRules:
+- supportsObservedGeneration: true
+  conditionMatchers:
+  - type: Ready
+    status: "True"
+    success: true
+  - type: ContainersReady
+    status: "False"
+    timeout: 50s
+  resourceMatchers:
+  - apiVersionKindMatcher: {apiVersion: v1, kind: Pod}
+`
+
 	name := "test-wait-timeout"
 	cleanUp := func() {
 		kapp.Run([]string{"delete", "-a", name})
@@ -67,4 +95,23 @@ func TestWaitTimeout(t *testing.T) {
 
 		require.NoErrorf(t, err, "Expected to be successful without resource timeout")
 	})
+
+	cleanUp()
+
+	logger.Section("Deploy timeout after staying in a condition for certain time", func() {
+		_, err := kapp.RunWithOpts([]string{"deploy", "-f", "-", "-a", name, "--json"},
+			RunOpts{IntoNs: true, AllowError: true, StdinReader: strings.NewReader(fmt.Sprintf(yaml2, "nginx:200"))})
+
+		require.Error(t, err)
+		require.Contains(t, err.Error(), "Continuously failed for 50s with")
+	})
+
+	cleanUp()
+
+	logger.Section("Deploy should be successful", func() {
+		_, err := kapp.RunWithOpts([]string{"deploy", "-f", "-", "-a", name, "--json"},
+			RunOpts{IntoNs: true, AllowError: true, StdinReader: strings.NewReader(fmt.Sprintf(yaml2, "nginx"))})
+
+		require.NoError(t, err)
+	})
 }
